using System;
using Server;
using Server.Mobiles;
using Server.Network;
using Server.Items;
using Server.Targeting;

namespace Server.Items
{
	public class ContributorSash : BodySash
  {
        private ItemDeleteTimer m_Timer;

		public override int BasePhysicalResistance{ get{ return 20; } } 
      
        [Constructable]
		public ContributorSash()
		{
            m_Timer = new ItemDeleteTimer(this);
            m_Timer.Start();

            Name = "Item Will Delete After 30 Days <BASEFONT COLOR=#CCCCCC>";
            Hue = 90;

            switch( Utility.Random( 3 ) )
			{
				case 0: //Pure Mage
					SkillBonuses.SetValues(0, SkillName.EvalInt, 10);
                    SkillBonuses.SetValues(1, SkillName.MagicResist, 10);
                    SkillBonuses.SetValues(2, SkillName.Magery, 10);
                    SkillBonuses.SetValues(3, SkillName.Inscribe, 10);
                    SkillBonuses.SetValues(4, SkillName.Meditation, 10);
					break;
				case 1: //Nox Mage
					SkillBonuses.SetValues(0, SkillName.EvalInt, 10);
                    SkillBonuses.SetValues(1, SkillName.MagicResist, 10);
                    SkillBonuses.SetValues(2, SkillName.Magery, 10);
                    SkillBonuses.SetValues(3, SkillName.Poisoning, 10);
                    SkillBonuses.SetValues(4, SkillName.Meditation, 10);
					break;
				case 2: //Warrior
					SkillBonuses.SetValues(0, SkillName.Swords, 10 );
                    SkillBonuses.SetValues(1, SkillName.Healing, 10);
					SkillBonuses.SetValues(2, SkillName.Tactics, 10 );
                    SkillBonuses.SetValues(3, SkillName.Anatomy, 10);
                    SkillBonuses.SetValues(4, SkillName.Lumberjacking, 10);
					break;			
			}

            Attributes.SpellChanneling = 1;
            Attributes.RegenMana = 3;
            Attributes.BonusMana = 8;
            Attributes.LowerRegCost = 100;

            Attributes.NightSight = 1;

            LootType = LootType.Blessed;
		}

        public override void GetProperties(ObjectPropertyList list)
        {
            list.Add("Contributor Sash");
            base.GetProperties(list);
        }

		public ContributorSash( Serial serial ) : base( serial )
		{
		}

        public override void OnAfterDelete()
        {
            if (m_Timer != null && m_Timer.Running)
                m_Timer.Stop();
        }

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 ); // version

            if (m_Timer != null)
                writer.Write(m_Timer.Next);
            else
                writer.Write(DateTime.Now);
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();

            DateTime next = reader.ReadDateTime();

            if (next < DateTime.Now)
            {
                m_Timer = new ItemDeleteTimer(this, next - DateTime.Now);
                m_Timer.Start();
            }
            else
                Delete();
		}

        private class ItemDeleteTimer : Timer
        {
            //Item Will Delete In 31 Days Or 744 Hours
            public static TimeSpan DefaultDelay { get { return TimeSpan.FromHours(744); } }

            private ContributorSash m_Item;

            public ItemDeleteTimer(ContributorSash item): this(item, DefaultDelay)
            {
            }

            public ItemDeleteTimer(ContributorSash item, TimeSpan delay): base(delay)
            {
                m_Item = item;
                Priority = TimerPriority.OneMinute;
            }

            protected override void OnTick()
            {
                if (m_Item != null && !m_Item.Deleted)
                    m_Item.Delete();
            }
        }
	}
}
